@@ -21,6 +21,7 @@
 package org.videolan.vlc;
 
 import android.annotation.TargetApi;
+import android.app.KeyguardManager;
 import android.app.Notification;
 import android.app.PendingIntent;
 import android.app.Service;
@@ -66,7 +67,6 @@ import org.videolan.libvlc.MediaList;
 import org.videolan.libvlc.MediaPlayer;
 import org.videolan.libvlc.util.AndroidUtil;
 import org.videolan.vlc.gui.AudioPlayerContainerActivity;
-import org.videolan.vlc.gui.browser.NetworkBrowserFragment;
 import org.videolan.vlc.gui.helpers.AudioUtil;
 import org.videolan.vlc.gui.preferences.PreferencesActivity;
 import org.videolan.vlc.gui.preferences.PreferencesFragment;
@@ -590,6 +590,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
     }
 
     private final MediaPlayer.EventListener mMediaPlayerListener = new MediaPlayer.EventListener() {
+        KeyguardManager keyguardManager = (KeyguardManager) VLCApplication.getAppContext().getSystemService(Context.KEYGUARD_SERVICE);
 
         @Override
         public void onEvent(MediaPlayer.Event event) {
@@ -625,7 +626,7 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                     changeAudioFocus(true);
                     if (!mWakeLock.isHeld())
                         mWakeLock.acquire();
-                    if (!mVideoBackground && switchToVideo())
+                    if (!keyguardManager.inKeyguardRestrictedInputMode() && !mVideoBackground && switchToVideo())
                         hideNotification(false);
                     else
                         showNotification();
@@ -905,12 +906,14 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
                 builder.addAction(R.drawable.ic_play_w, getString(R.string.play), piPlay);
             builder.addAction(R.drawable.ic_next_w, getString(R.string.next), piForward);
 
-            builder.setStyle(new NotificationCompat.MediaStyle()
-                            .setMediaSession(mMediaSession.getSessionToken())
-                            .setShowActionsInCompactView(new int[] {0,1,2})
-                            .setShowCancelButton(true)
-                            .setCancelButtonIntent(piStop)
-            );
+            if (AndroidDevices.showMediaStyle) {
+                builder.setStyle(new NotificationCompat.MediaStyle()
+                                .setMediaSession(mMediaSession.getSessionToken())
+                                .setShowActionsInCompactView(new int[] {0,1,2})
+                                .setShowCancelButton(true)
+                                .setCancelButtonIntent(piStop)
+                );
+            }
 
             notification = builder.build();
 
@@ -1346,13 +1349,13 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         loadLocations(mediaPathList, position);
         if (time > 0)
             seek(time);
-        if(!audio) {
+        if (!audio) {
             boolean paused = mSettings.getBoolean(PreferencesActivity.VIDEO_PAUSED, !isPlaying());
             float rate = mSettings.getFloat(PreferencesActivity.VIDEO_SPEED, getRate());
             if (paused)
                 pause();
             if (rate != 1.0f)
-                setRate(rate);
+                setRate(rate, false);
         }
         SharedPreferences.Editor editor = mSettings.edit();
         editor.putInt(audio ? "position_in_audio_list" : "position_in_media_list", 0);
@@ -1700,7 +1703,9 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         final MediaWrapper mw = mMediaList.getMedia(index);
         if (mw == null)
             return;
-        if (!mVideoBackground && mw.getType() == MediaWrapper.TYPE_VIDEO && isVideoPlaying())
+
+        boolean isVideoPlaying = isVideoPlaying();
+        if (!mVideoBackground && mw.getType() == MediaWrapper.TYPE_VIDEO && isVideoPlaying)
             mw.addFlags(MediaWrapper.MEDIA_VIDEO);
 
         if (mVideoBackground)
@@ -1737,11 +1742,13 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
         media.release();
 
         if (mw .getType() != MediaWrapper.TYPE_VIDEO || mw.hasFlag(MediaWrapper.MEDIA_FORCE_AUDIO)
-                || isVideoPlaying()) {
+                || isVideoPlaying) {
             mMediaPlayer.setEqualizer(VLCOptions.getEqualizer(this));
             mMediaPlayer.setVideoTitleDisplay(MediaPlayer.Position.Disable, 0);
             changeAudioFocus(true);
             mMediaPlayer.setEventListener(mMediaPlayerListener);
+            if (!isVideoPlaying && mMediaPlayer.getRate() == 1.0F && mSettings.getBoolean(PreferencesActivity.KEY_AUDIO_PLAYBACK_SPEED_PERSIST, false))
+                setRate(mSettings.getFloat(PreferencesActivity.KEY_AUDIO_PLAYBACK_RATE, 1.0F), true);
             mMediaPlayer.play();
 
             determinePrevAndNextIndices();
@@ -1945,8 +1952,10 @@ public class PlaybackService extends Service implements IVLCVout.Callback {
     }
 
     @MainThread
-    public void setRate(float rate) {
+    public void setRate(float rate, boolean save) {
         mMediaPlayer.setRate(rate);
+        if (save && mSettings.getBoolean(PreferencesActivity.KEY_AUDIO_PLAYBACK_SPEED_PERSIST, false))
+            Util.commitPreferences(mSettings.edit().putFloat(PreferencesActivity.KEY_AUDIO_PLAYBACK_RATE, rate));
     }
 
     @MainThread
