@@ -39,6 +39,7 @@ import android.widget.Toast;
 import org.videolan.libvlc.util.HWDecoderUtil;
 import org.videolan.vlc.BuildConfig;
 import org.videolan.vlc.R;
+import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.helpers.AudioUtil;
 import org.videolan.vlc.gui.helpers.BitmapCache;
 import org.videolan.vlc.media.MediaDatabase;
@@ -121,7 +122,7 @@ public class Advanced extends BasePreferenceFragment implements SharedPreference
         setLocalePref.setOnPreferenceChangeListener(new Preference.OnPreferenceChangeListener() {
             @Override
             public boolean onPreferenceChange(Preference preference, Object newValue) {
-                Toast.makeText(getActivity(), R.string.set_locale_popup, Toast.LENGTH_SHORT).show();
+                Toast.makeText(VLCApplication.getAppContext(), R.string.set_locale_popup, Toast.LENGTH_SHORT).show();
                 return true;
             }
         });
@@ -164,7 +165,7 @@ public class Advanced extends BasePreferenceFragment implements SharedPreference
                 BitmapCache.getInstance().clear();
                 AudioUtil.clearCacheFolders();
                 getActivity().setResult(PreferencesActivity.RESULT_RESCAN);
-                Toast.makeText(getActivity(), R.string.media_db_cleared, Toast.LENGTH_SHORT).show();
+                Toast.makeText(VLCApplication.getAppContext(), R.string.media_db_cleared, Toast.LENGTH_SHORT).show();
                 return true;
             case "quit_app":
                 android.os.Process.killProcess(android.os.Process.myPid());
