@@ -77,6 +77,10 @@ public class VLCOptions {
         else if (networkCaching < 0)
             networkCaching = 0;
 
+        final String freetypeRelFontsize = pref.getString("subtitles_size", "16");
+        final String freetypeColor = pref.getString("subtitles_color", "16777215");
+        final boolean freetypeBackground = pref.getBoolean("subtitles_background", false);
+
         /* CPU intensive plugin, setting for slow devices */
         options.add(timeStreching ? "--audio-time-stretch" : "--no-audio-time-stretch");
         options.add("--avcodec-skiploopfilter");
@@ -96,6 +100,13 @@ public class VLCOptions {
         options.add("--audio-resampler");
         options.add(getResampler());
 
+        options.add("--freetype-rel-fontsize=" + freetypeRelFontsize);
+        options.add("--freetype-color=" + freetypeColor);
+        if (freetypeBackground)
+            options.add("--freetype-background-opacity=128");
+        else
+            options.add("--freetype-background-opacity=0");
+
         /* Configure keystore */
         options.add("--keystore");
         if (AndroidUtil.isMarshMallowOrLater())
@@ -152,7 +163,7 @@ public class VLCOptions {
 
     private static String getResampler() {
         final VLCUtil.MachineSpecs m = VLCUtil.getMachineSpecs();
-        return m.processors > 2 ? "soxr" : "ugly";
+        return (m == null || m.processors > 2) ? "soxr" : "ugly";
     }
 
     public static void setMediaOptions(Media media, Context context, int flags) {
